
/**
	Set contents of the tag with given id.
*/
function setInnerHTML(id, html)
{
	var tag = document.getElementById(id);
	if (!tag) alert('No tag with id='+id);
	tag.innerHTML = html;
}

/**
	Execute the given method when the TAB key is pressed. A short
	delay is added so the method doesn't interfer with normal event
	handling.
	
	@param event The event object with information about what happened
	@param method The method to execute when TAB is pressed
*/
function doOnTab(event, method)
{
	if (event.keyCode == 9) 
	{
		setTimeout(method, 200);
	}
	return true;
}

/**
	Execute the given method when the TAB or ENTER key is pressed. 
	A short delay is added so the method doesn't interfer with normal 
	event handling.
	
 	@param event The event object with information about what happened
	@param method The method to execute when TAB is pressed
 */
function doOnTabOrEnter(event, method)
{
	if (event.keyCode == 9 || event.keyCode == 13) 
	{
		setTimeout(method, 200);
	}
	return true;
}

/**
	Switch focus to the given input field if the ENTER key is pressed.
	If no form name is given, the input field must be on the same form
	as the field that receives the event.
	
 	@param event The event object with information about what happened
 	@param inputFieldName The name of the input field which should get focus next
*/
function focusOnEnter(event, inputFieldName, formName)
{
	if (event.keyCode == 13) 
	{
		var frm;
		if (formName)
		{
			frm = document.forms[formName];
		}
		else
		{
			var currentField = event.target || event.srcElement;
			if (currentField) frm = currentField.form;
		}
		if (frm)
		{
			var nextField = frm[inputFieldName];
			if (nextField) nextField.focus();
		}
	}
	return true;
}

/**
	Set status for an input field.
	@param prefix The prefix to use for finding <div> and other tags
	@param message The message (may be empty)
	@param clazz The message clazz (valid, invalid, warning) or empty
*/
function setInputStatus(prefix, message, clazz)
{
	var tag = document.getElementById(prefix + '.status');
	tag.className = 'status ' + clazz;
	
	setInnerHTML(prefix + '.message', message);
	if (message)
	{
		Main.showInline(prefix + '.message');
	}
	else
	{
		Main.hide(prefix + '.message');
	}
}

/**
	Display a fatal error message and disable all form controls and
	hide all buttons except the 'gorestart' button. A <div> tag with
	the id=errorMessage is assumed.
	
	@param message The error message to display
*/
function setFatalError(message)
{
	setInnerHTML('errorMessage', message);
	Main.show('errorMessage');
	var buttons = Main.getElementsByTagAndClassName('div', 'buttonclass');
	if (buttons.length == 0) buttons = Main.getElementsByTagAndClassName('div', 'basicbutton');
	for (var i = 0; i < buttons.length; i++)
	{
		if (buttons[i].id) buttons[i].style.display = 'none';
	}
	Main.show('gorestart');
	for (var fi = 0; fi < document.forms.length; fi++)
	{
		var frm = document.forms[fi];
		for (var ei = 0; ei < frm.elements.length; ei++)
		{
			frm.elements[ei].disabled = true;	
		}
	}
}

/**
	Cancel the current registration and re-start the wizard from the beginning.
	@param force If set, the wizard is re-started without confirmation
*/
function goRestart(force)
{
	if (!force && !confirm('Cancel this registration?')) return;
	location.href = location.href;
}

/**
	Check the control digit of the given personal number.
	@pnr The 10-digit personal number in the form YYMMDDXXXX
*/
function personalNumberControlDigitCheck(pnr)
{
	var sum = 0;
	var factor = 2;
	for (var i = 0; i < 9; i++)
	{
		var digit = parseInt(pnr.substr(i, 1));
		var tmp = factor * digit;
		sum += tmp >= 10 ? tmp - 9: tmp;
		factor = factor == 2 ? 1 : 2;
	}
	
	var control = 10 - (sum % 10);
	if (control == 10) control = 0;
	return (control == parseInt(pnr.substr(9, 1)))
}

/**
	Convert a 2-digit year to a 4-digit year. Assuming
	that the short year is between 1 and 100 years old. 
*/
function fullYear(shortYear)
{
	var thisYear = new Date().getFullYear();
	var fullYear = shortYear + 100*Math.floor((thisYear - shortYear - 1) / 100);
	return fullYear;
}

/**
	Autofill a date-string.
	The supplemented date-string will have the format yyyyMMdd when it's returned.
	If the short-date in format MMdd is larger the current date, the year before will be used.
	
	@param shortDate Date in format 'MMdd' or in 'yyMMdd'
*/
function autoFillDate(shortDate)
{
	shortDate = shortDate.replace("-","")
	var fullDateString = shortDate;
	
	var currentDate = new Date();
	var currentYear = currentDate.getFullYear();
	if (shortDate.length == 4 && Dates.isDate(shortDate, 'MMdd'))
	{
		var month = parseInt(shortDate.substring(0,2));
		var date = parseInt(shortDate.substring(2));
		if ((month > (currentDate.getMonth()+1))  ||
				( (month == (currentDate.getMonth()+1)) && (date > currentDate.getDate())) )
		{
			currentYear--;
		}
		fullDateString = currentYear+shortDate;
	}
	else if (shortDate.length == 6 && Dates.isDate(shortDate, 'yyMMdd'))
	{
		var year = parseInt(shortDate.substring(0,2));		
		fullDateString = ((2000+year)>currentYear ? "19" : "20") + fullDateString;
	}	
	return fullDateString;	
}

function autoFillTime(shortTime)
{
	
	var fullTimeString = shortTime;
	if (shortTime.length==3) 
	{
		fullTimeString = "0"+shortTime;
	}
	return fullTimeString;
}

function getWeekByDate(currentDate)
{
	var weeknum;	
	var newYear = new Date(currentDate.getFullYear(),0,1);
	var numdays = Math.ceil((currentDate.getTime() - newYear.getTime()) / (1000 * 60 * 60 * 24));
	var day = newYear.getDay()-1;
	day = day>=0 ? day : day+7;
	var offset = day < 3 ? day : day-7;
	
	if ( (numdays+offset) > 0 )
	{
		weeknum = Math.ceil((numdays + offset) / 7);
	}
	else
	{
		// Current week belongs to the year before.
		weeknum = getWeekByDate(new Date(currentDate.getFullYear()-1, 11, 31));
	}
			
	// If the last day of the year is on a monday or thuesday. 
	if (weeknum > 52)
	{
		var nYear = new Date(newYear.getFullYear()+1, 0, 1);
		var nday = nYear.getDay()-1;
		nday = nday >=0 ? nday : nday+7;
		weeknum = nday < 4 ? 1 : 53;
	}
	return weeknum;
}

/*
	Verify that the 'case' name is a 7-digit value.
 */
function isValidCaseName(caseName)
{
	return caseName.match(/^\d{7}$/);
}

/**
	Get the selected value from a selection list.
*/
function getSelectedValue(list)
{
	if (list.selectedIndex < 0) return '';
	return list[list.selectedIndex].value;
}
/**
	Select the first option in the list that has the given value.
*/
function setSelectedValue(list, value)
{
	for (var i = 0; i < list.length; i++)
	{
		if (list[i].value == value)
		{
			list.selectedIndex = i;
			return;
		}
	}
}


